Class: Blankity::Top

Inherits:
BasicObject
Defined in:
lib/blankity/top.rb

Overview

A Class that has no instance methods on it whatsoever.

This is actually pretty difficult to use properly, as some methods (e.g. initialize and singleton_method_defined) are expected by Ruby to always exist, and restrict a lot of builtin functionality. (For example, without singleton_method_defined, you can’t actually define singleton methods _at all_.)

See Also: